@@ -5,7 +5,7 @@ print("except");
 }
        }
 if (1!=2){
-    print("ihihih");
+    print("\'ihihih\'");
     print({"hi":1}["hi"]);
 }
 
@@ -17,6 +17,13 @@ def hello(){
     print("hello\"");
 }
 
+print(true || false) // you dont have to use capital T and F in true and false.
+
+def indentation():
+    print("You dont have to use the braces, the regular indentation works too")
+
+
+anotherTest()
 
 dict = {"hello":1};
 
